# 59. Амплитуда, период, частота, длин волны, дискретизация, частота дискретизации, герц, угловая частота, фаза сигнала.

Амплитуда - разница между максимальным значением и базовой линией.

Период волны - время, за которое волна проходит полный цикл.

Частота - количество волн, проходящих через фиксированное место за определенное время. Измеряется в количестве циклов за 1 секунду. Единицей является Герц.

Период = 1 / Частота

Длина волны - расстояние между двумя последовательными гребнями.

Дискретизация - как часто мы измеряем значения волны во времени.

Частота дискретизации - скорость дискретизации, измеряется в Гц.

Герц - частота колебаний за одну секунду (например если мы дискретизируем волну с частотой 2 Гц, значит, каждую секунду мы фиксируем два значения).

Угловая частота - количество циклов за секунду. Измеряется в радианах в секунду.

Фаза сигнала - это положение волны во времени относительно точки отсчета, отвечает за сдвиги волн вправо-лево. Измеряется в градусах или радианах.